﻿-- Author      : Potdisc
-- Create Date : 5/24/2012 6:24:55 PM
-- options.lua - option frame in BlizOptions for RCLootCouncil
local addon = LibStub("AceAddon-3.0"):GetAddon("RCLootCouncil")

------ Options ------
function addon:OptionsTable()
	local db = addon.db.profile
	local options = { 
		name = "RCLootCouncil",
		type = "group",
		childGroups = "tab",
		args = {
			toggle = {
				order = 1,
				name = "Toggle usage",
				desc = "Check to manually toggle usage on/off - needed in case you change your mind after entering a raid.\nDon't touch it if you're not the Master Looter as it won't do anything.",
				type = "toggle",
				set = function() RCLootCouncil.isRunning() end,
				get = function() return RCLootCouncil:GetVariable("isRunning") end
			},
			toggleAdvanced = {
				order = 2,
				name = "Toggle Advanced Options",
				desc = "Check to show advanced options such as changing loot buttons/responses, toggle different looting, announcement options and voting types.",
				type = "toggle",
				width = "double",
				get = function() return self.db.profile.advancedOptions end,
				set = function() self.db.profile.advancedOptions = not self.db.profile.advancedOptions; end,
			},
			generalSettings = {
				order = 1,
				type = "group",
				name = "General Settings",
				args = {
					windowsDesc = {
						order = 1,
						name = "Window options\n",
						type = "description",
					},
					show = {
						name = "Show",
						desc = "Show the Mainframe",
						type = "execute",
						order = 2,
						func = function()
							if not IsInRaid() or RCLootCouncil:GetVariable("isCouncil") or RCLootCouncil:GetVariable("isMasterLooter") then
								RCLootCouncil_Mainframe.showMainFrame()
							else
								addon:Print("You cannot see the voting frame unless you're a member of the council.")
							end
						end,
					},
					hide = {
						name = "Hide",
						desc = "Hide the Mainframe",
						type = "execute",
						order = 3,
						func = function() RCLootCouncil_Mainframe.hideMainFrame() end
					},
					versionTest = {
						name = "Version Check",
						desc = "Click to check for updates and see who has the addon installed",
						type = "execute",
						order = 3.1,
						func = function()
							RCLootCouncil:EnableModule("RCLootCouncil_VersionFrame");
							InterfaceOptionsFrame:Hide();
						end

					},
					header1 = {
						order = 4,
						name = "",
						type = "header"
					},
					testButton = {
						order = 6,
						name = "Solo test",
						desc = "Click to emulate master looter looting an item for yourself only (not possible in a raid)",
						type = "execute",
						func = function()
							InterfaceOptionsFrame:Hide(); -- close all option frames before testing
							RCLootCouncil_Mainframe.testFrames()
						end			
					},
					testRaidButton = {
						order = 6.1,
						name = "Raid Test",
						desc = "Click to emulate master looter looting an item (requires you to be in an raid and be the master looter)",
						type = "execute",
						func = function()
							if UnitIsGroupLeader("player") then
								RCLootCouncil_Mainframe.raidTestFrames()
								InterfaceOptionsFrame:Hide();
							else
								addon:Print("Cannot start raid test when you're not in a raid or the raid leader.")
							end
						end
					},
					testDesc = {
						order = 5,
						name = "\nTest RCLootCouncil\n\nClick to view how the frames will appear when the master looter loots an item.\nThis is the only way to test out RCLootCouncil without being in an actual instance.\n",
						type = "description"	
					},
					header2 = {
						order = 7,
						name = "",
						type = "header"
					},
					voteDesc = {
						order = 8,
						name = "Voting options\n",
						type = "description"
					},
					selfVoteToggle = {
						order = 9,
						name = "Vote for self",
						desc = "Check to enable councilmembers ability to vote for themselves.",
						type = "toggle",
						get = function() return self.db.profile.selfVote end,
						set = function() self.db.profile.selfVote = not self.db.profile.selfVote end,
					},
					multiVoteToggle = {
						order = 9.1,
						name = "Multi Vote",
						desc = "Check to enable multi voting, i.e. more than 1 vote per player.",
						type = "toggle",
						get = function() return self.db.profile.multiVote end,
						set = function() self.db.profile.multiVote = not self.db.profile.multiVote; end,
					},
					acceptWhispers = {
						order = 9.3,
						name = "Accept whispers",
						desc = "Check to allow players without the addon to whisper their current items to you to get added to the consideration list.",
						type = "toggle",
						hidden = function() return not self.db.profile.advancedOptions; end,
						get = function() return self.db.profile.acceptWhispers end,
						set = function() self.db.profile.acceptWhispers = not self.db.profile.acceptWhispers end,
					},
					anonymousVotingToggle = {
						order = 10,
						name = "Anonymous Voting",
						desc = "Check to enable anonymous voting, i.e. see whom is voting for who.",
						type = "toggle",
						hidden = function() return not self.db.profile.advancedOptions; end,
						get = function() return self.db.profile.anonymousVoting end,
						set = function()
							self.db.profile.anonymousVoting = not self.db.profile.anonymousVoting;
							if not self.db.profile.anonymousVoting then 
								self.db.profile.masterLooterOnly = false
							end 
						end,
					},
					masterLooterOnly = {
						order = 10.1,
						name = "Show for the ML only",
						desc = "Check to only show the tooltip from Anonymous voting to the Masterlooter.",
						type = "toggle",
						disabled = function() return not self.db.profile.anonymousVoting; end,
						hidden = function() return not self.db.profile.advancedOptions; end,
						get = function() return self.db.profile.masterLooterOnly end,
						set = function() self.db.profile.masterLooterOnly = not self.db.profile.masterLooterOnly end,
					},					
					header3 = {
						order = 11,
						name = "",
						type = "header",
					},
					lootDesc = {
						order = 12,
						name = "Looting options\n",
						type = "description",
					},
					autoLooting = {
						order = 12.1,
						name = "Auto Looting",
						desc = "Check to enable Auto Looting, i.e. the addon automatically starts looting whenever it can.",
						type = "toggle";
						get = function() return self.db.profile.autoLooting end,
						set = function() self.db.profile.autoLooting = not self.db.profile.autoLooting; end,
					},
					lootEverything = {
						order = 12.2,
						name = "Loot Everything",
						desc = "Check to enable looting of non-items (e.g. mounts, tier-tokens)",
						type = "toggle",
						disabled = function() return not self.db.profile.autoLooting; end,
						get = function() return self.db.profile.lootEverything end,
						set = function() self.db.profile.lootEverything = not self.db.profile.lootEverything; end,
					},
					boeLoot = {
						order = 12.3,
						name = "Autoloot BoE",
						desc = "Check to enable autolooting of BoE (Bind on Equip) items.",
						type = "toggle",
						disabled = function() return not self.db.profile.autoLooting; end,
						hidden = function() return not self.db.profile.advancedOptions; end,
						get = function() return self.db.profile.autolootBoE; end,
						set = function() self.db.profile.autolootBoE = not self.db.profile.autolootBoE; end,
					},
					altClickLooting = {
						order = 12.4,
						name = "Alt click looting",
						desc = "Check to enable alt click looting, i.e. start a looting session by holding down alt and (left)clicking an item.",
						type = "toggle",
						hidden = function() return not self.db.profile.advancedOptions; end,
						get = function() return self.db.profile.altClickLooting end,
						set = function() self.db.profile.altClickLooting = not self.db.profile.altClickLooting; end,
					},
					header4 = {
						order = 13,
						name = "",
						type = "header",
					},
					outputDesc = {
						order = 14,
						name = "\nAnnouncement options\n\nSelect which message you want to announce to which channel when awarding loot, or none to toggle announcement off. You can announce in 2 channels at once.\nUse &p for the name of the player getting the loot and &i for the item awarded.",
						type = "description",
						hidden = function() return not self.db.profile.advancedOptions; end,
					},
					outputMessage = {
						order = 15,
						name = "Message 1 text",
						desc = "The message to be displayed when awarding an item.",
						type = "input",
						width = "double",
						get = function() return self.db.profile.awardMessageText1 end,
						set = function(i,v) self.db.profile.awardMessageText1 = v; end,
						hidden = function() return not self.db.profile.advancedOptions; end,
					},
					outputSelect = {
						order = 15.1,
						name = "Announcement 1 channel",
						desc = "Select which channel to announce rewards in or none to toggle announcing off.",
						type = "select",
						style = "dropdown",
						values = {
							NONE = "None",
							SAY = "Say",
							YELL = "Yell",
							PARTY = "Party",
							GUILD = "Guild",
							OFFICER = "Officer",
							RAID = "Raid",
							RAID_WARNING = "Raid Warning"
						},
						set = function(i,v) self.db.profile.awardMessageChat1 = v end,
						get = function() return self.db.profile.awardMessageChat1 end,
						hidden = function() return not self.db.profile.advancedOptions; end,
					},
					outputMessage2 = {
						order = 16,
						name = "Message 2 text",
						desc = "The message to be displayed when awarding an item.",
						type = "input",
						width = "double",
						get = function() return self.db.profile.awardMessageText2 end,
						set = function(i,v) self.db.profile.awardMessageText2 = v; end,
						hidden = function() return not self.db.profile.advancedOptions; end,
					},
					outputSelect2 = {
						order = 16.1,
						name = "Announcement 2 channel",
						desc = "Select which channel to announce rewards in or none to toggle announcing off.",
						type = "select",
						style = "dropdown",
						values = {
							NONE = "None",
							SAY = "Say",
							YELL = "Yell",
							PARTY = "Party",
							GUILD = "Guild",
							OFFICER = "Officer",
							RAID = "Raid",
							RAID_WARNING = "Raid Warning"
						},
						set = function(i,v) self.db.profile.awardMessageChat2 = v end,
						get = function() return self.db.profile.awardMessageChat2 end,
						hidden = function() return not self.db.profile.advancedOptions; end,
					},
				},
			},
			moreOptions = {
				order = 2,
				type = "group",
				name = "\"Roll\" buttons and Responses",
				hidden = function() return not self.db.profile.advancedOptions; end,
				args = {
					optionsDesc = {
						order = 0,
						name = "Configure the reply buttons on the raiders' loot frame as well as the corresponding response and color to be showed on the council frame.\nThe lowest number button is showed furthest to the left and the highest furthes to the right - use the slider to choose how many buttons you want (max "..self.db.profile.maxButtons..").\n\nThe first button is always activated and will count as MainSpec in the loot history.",
						type = "description"
					},
					buttonsRange = {
						order = 1,
						name = "Number of buttons",
						desc = "Slide to toggle the number of buttons to display on the loot frame.",
						type = "range",
						width = "full",
						min = 1,
						max = self.db.profile.maxButtons,
						step = 1,
						get = function() return self.db.profile.numButtons; end,
						set = function(i,v) self.db.profile.numButtons = v; end,
					},
					header1 = {
						order = 70,
						name = "",
						type = "header"
					},
					reset = {
						order = 71,
						name = "Reset to default",
						desc = "Resets all the buttons, colors and responses to default",
						type = "execute",
						func = function() addon:toDefault() end
					},
				},
			},
			lootHistory = {
				order = 3,
				type = "group",
				name = "Loot History options",
				hidden = function() return not self.db.profile.advancedOptions; end,
				args = {
					desc1 = {
						order = 1,
						name = "The Loot History is still a work in progress - for now it logs all data and displays them in a simple view. This will get more refined as i get more time.\n",
						type = "description",
					},
					trackLooting = {
						order = 2,
						name = "Track Awards",
						desc = "Check to enable tracking of awards, i.e. log all awards for a later presentation.",
						type = "toggle",
						get = function() return self.db.profile.trackAwards; end,
						set = function() self.db.profile.trackAwards = not self.db.profile.trackAwards; end,
					},
					openLootDB = {
						order = 3,
						name = "Open the Loot History",
						desc = "Click to open the RCLootCouncil Loot History.",
						type = "execute",
						func = function() RCLootCouncil:EnableModule("RCLootHistory");	InterfaceOptionsFrame:Hide();end,
					},
					clearLootDB = {
						order = 90,
						name = "Clear Loot History",
						desc = "Delete the entire loot history.",
						type = "execute",
						func = function() self.db.factionrealm.lootDB = {} end,
						confirm = true,
					},
				},
			},
			council = {
				order = 4,
				type = "group",
				name = "Council",
				childGroups = "tab",
				args = {
					currentCouncil = {
						order = 1,
						type = "group",
						name = "Current Council",
						args = {
							currentCouncilDesc = {
								order = 1,
								name = "\nClick to remove certain people from the council\n",
								type = "description",
							},
							councilList = {
								order = 2,
								type = "multiselect",
								name = "",
								values = function()
									local t = {}
									for k,v in ipairs(self.db.profile.council) do t[k] = ""..v end
									return t;
								end,
								width = "full",
								get = function() return true end,
								set = function(m,key) tremove(self.db.profile.council,key) end,
							},							
							removeAll = {
								order = 3,
								name = "Remove All",
								desc = "Remove all council members",
								type = "execute",
								confirm = true,
								func = function() self.db.profile.council = {} end,							
							},
						},
					},
					addCouncil = {
						order = 2,
						type = "group",
						name = "Edit Council Members",
						childGroups = "tree",
						args = {
							addRank = {
								order = 1,
								name = "Add ranks",
								type = "group",
								args = {
									header1 = {
										order = 1,
										name = "Choose minimum rank to participate in lootcouncil:",
										type = "header",
										width = "full",
									},
									selection = {
										order = 2,
										name = "",
										type = "select",
										width = "full",
										values = function()
											GuildRoster();
											local info = {};
											for ci = 1, GuildControlGetNumRanks() do 
												info[ci] = " "..ci.." - "..GuildControlGetRankName(ci);
											end
											return info
										end,
										set = function(j,i) self.db.profile.council = {}; RCLootCouncil_Mainframe.setRank(i); end,
										get = function() return self.db.profile.minRank; end,
									},
									desc = {
										order = 3,
										name = "\n\nSelect a rank above to add all members at and above that rank to the council.\n\nClick on the ranks to the left to add individual players to the council.\n\nClick the 'Current Council' tab to see your selection.",
										type = "description",
									},
								},
							},
							spacer = {
								order = 2,
								name = "",
								type = "group",
								args = {}
							}
						},
					},
				},
			},
		},
	}
	
	-- make the buttons config
	local button, picker, text = {}, {}, {}
	for i = 1, self.db.profile.maxButtons do	
		button = {
			order = i * 3 + 1,
			name = "Button "..i,
			desc = "Set the text on button "..i..".",
			type = "input",
			get = function() return self.db.profile.buttons[i]["text"] end,
			set = function(info, value)	self.db.profile.buttons[i]["text"] = tostring(value) end,
			hidden = function() if self.db.profile.numButtons < i then return true; else return false; end end
		}
		options.args.moreOptions.args["button"..i] = button;
		picker = {
			order = i * 3 + 1,
			name = "Response color",
			desc = "Set a text color for the response",
			type = "color",
			get = function()
				local r = self.db.profile.buttons[i]["color"][1]
				local g = self.db.profile.buttons[i]["color"][2]
				local b = self.db.profile.buttons[i]["color"][3]
				return r,g,b
			end,
			set = function(info,r,g,b)
			local color = {r,g,b,1}
			self.db.profile.buttons[i]["color"] = color
			end,
			hidden = function() if self.db.profile.numButtons < i then return true; else return false; end end,
		}
		options.args.moreOptions.args["picker"..i] = picker;
		text = {	
			order = i * 3 + 3,
			name = "Response",
			desc = "Set the text for button "..i.."'s response.",
			type = "input",
			get = function() return self.db.profile.buttons[i]["response"] end,
			set = function(info, value) self.db.profile.buttons[i]["response"] = tostring(value) end,
			hidden = function() if self.db.profile.numButtons < i then return true; else return false; end end,		
		}
		options.args.moreOptions.args["text"..i] = text;
	end
	return options
end

function RCLootCouncil:GetGuildOptions()
	for i = 1, GuildControlGetNumRanks() do
		local rank = GuildControlGetRankName(i)
		local names = {}

	-- Define the individual option:
		local option = {
			order = i + 2,
			name = rank,
			type = "group",
			args = {
				ranks = {
					order = i,
					name = ""..rank,
					type = "multiselect",
					width = "full",
					values = function()
						wipe(names)
						for ci = 1, GetNumGuildMembers() do
							local name, rank1, rankIndex = GetGuildRosterInfo(ci);
						if (rankIndex + 1) == i then tinsert(names, name) end
						end
						table.sort(names, function(v1, v2)
							return v1 and v1 < v2
						end)
						return names
					end,
					get = function(info, number)
						local values = addon.options.args.council.args.addCouncil.args[info[#info-1]].args.ranks.values()
						for j = 1, #self.db.profile.council do
							if values[number] == self.db.profile.council[j] then return true end
						end
						return false
					end,
					set = function(info, number, tag)
						local values = addon.options.args.council.args.addCouncil.args[info[#info-1]].args.ranks.values()
						if tag then tinsert(self.db.profile.council, values[number])
						else
							for k,v in ipairs(self.db.profile.council) do
								if v == values[number] then
								tremove(self.db.profile.council, k)
								end
							end
						end
					end,
				},
			},
		}

		-- Add it to the guildMembersGroup arguments:
		self.options.args.council.args.addCouncil.args[i..""..rank] = option
	end
end
